@@ -1,6 +1,8 @@
 from __future__ import absolute_import
 
 from .block import Division, Paragraph, Preformatted
+from .document import (Document, HTMLRoot, Head, Body, Title, Meta, Script,
+                       HeadLink, Main)
 from .element import (Element, VoidElement,
                       html_attribute, boolean_html_attribute,
                       int_html_attribute)
@@ -8,3 +10,5 @@ from .generator import (Generator, NullGenerator, ChildGenerator,
                         HTMLChildGenerator, JoinGenerator, HTMLJoinGenerator)
 from .image import Image
 from .inline import Span, Highlight, Strong, Alternate, Emphasis, Small
+from .list import OrderedList, UnorderedList, ListItem
+from .structure import Section, Navigation, Aside, Header, Footer, Heading
